// MiscMath.h  Misc. math functions
// Copyright 2006 Chad Berchek

// See revision history in miscmath.cpp.

#ifndef MISCMATH_H
#define MISCMATH_H

#include <cmath>
using namespace std;

const double M_2PI = 2. * M_PI;

// fpart(x) returns the decimal part of the number
#define fpart(X) fmod((X), 1.)

// isWithin and isWithinD
// True if i and j are within n of each other.
// Example: isWithin(3,5,2) is true. isWithin(4,7,2) is false.
// isWithinD works with doubles
#define isWithin(i, j, n) (abs((i)-(j)) <= (n))
#define isWithinD(i, j, n) ( fabs( double(i) - double(j) ) <= double(n) )

// Rounds a floating point number. If the decimal part is >=.5 it rounds up, else down, for
// a positive number. If the decimal part is <=.5 it rounds down, else up, for a negative number.
double fround(double x);

// Returns atan2 of the given numbers. In case x==y==0 it returns 0.
double safeAtan2(double x, double y);

// Maps input angle to interval +pi to -pi by adding or subtracting 2pi.
double mapToPi(double tmp);

#endif
